==> haskell-reducers-3.12.2-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.2
id: reducers-3.12.2-9BA5JgeLB8gK5Gz1fpAuVr
key: reducers-3.12.2-9BA5JgeLB8gK5Gz1fpAuVr
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union
abi: c25ad3f0ceed402b96d10794629feb31
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/reducers-3.12.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/reducers-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/reducers-3.12.2
hs-libraries: HSreducers-3.12.2-9BA5JgeLB8gK5Gz1fpAuVr
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    fingertree-0.1.3.1-DIZm51l9CXO8N2c2fFYs7K
    hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    semigroupoids-5.2.2-8EKgbNnHj7C9jW0bxRAB0c
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj transformers-0.5.2.0
    unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             fingertree-0.1.3.1-DIZm51l9CXO8N2c2fFYs7K=1be1922b1a3aacf357da2e30e765fd19
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=e2c3f4e35e60b5547d3e7a8c501ca6de
             semigroupoids-5.2.2-8EKgbNnHj7C9jW0bxRAB0c=6fdfcc546a97b362d478106b5598899c
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=d64b81e3ed8022aca04423ee7b330679
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.8.0-YOGDwOwys3HjU5i3g27KB=1ae4406c8abf6f6a305796d42b6e1b7b
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reducers-3.12.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reducers.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reducers
version: 3.12.2
id: reducers-3.12.2-I2Ot9yB2Bf9DM1EiBmNsfY
key: reducers-3.12.2-I2Ot9yB2Bf9DM1EiBmNsfY
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/reducers/
synopsis: Semigroups, specialized containers and a general map/reduce framework
description:
    Semigroups, specialized containers and a general map/reduce framework
category: Data, Math, Numerical, Semigroups
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Generator Data.Generator.Combinators Data.Semigroup.Alt
    Data.Semigroup.Alternative Data.Semigroup.Applicative
    Data.Semigroup.Apply Data.Semigroup.Generator
    Data.Semigroup.Instances Data.Semigroup.Monad
    Data.Semigroup.MonadPlus Data.Semigroup.Reducer
    Data.Semigroup.Reducer.With Data.Semigroup.Self
    Data.Semigroup.Union
abi: 490fb7f030ba124759a96d7790d90cf3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/reducers-3.12.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/reducers-3.12.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/reducers-3.12.2
hs-libraries: HSreducers-3.12.2-I2Ot9yB2Bf9DM1EiBmNsfY
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    fingertree-0.1.3.1-F9ScKsAdn1n6OkakzqLTRD
    hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk
    semigroupoids-5.2.2-8ZtOWrOYrUnL0zPLyQ3GNy
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz transformers-0.5.2.0
    unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             fingertree-0.1.3.1-F9ScKsAdn1n6OkakzqLTRD=d7351ce314efe14eb0244de484921c11
             hashable-1.2.6.1-A4keFPUppGkCw7JMX4jBTk=526c49aca960d0292e5723576545a03d
             semigroupoids-5.2.2-8ZtOWrOYrUnL0zPLyQ3GNy=e33df6e1251f1ffaa58802fd3ec22d0c
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             unordered-containers-0.2.9.0-G7T2IXGR99p4cQdXRUBkNA=bcd116646f2dca4381cb4b7cc7ba7fb1
haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
haddock-html: /usr/share/doc/haskell-reducers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
